#
# spec file for package nextcloud-client
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname  libnextcloudsync
%define sover   0
Name:           nextcloud-client
Version:        2.5.3
Release:        lp151.2.3.1
Summary:        Nextcloud desktop synchronisation client
License:        GPL-2.0-or-later AND LGPL-3.0-or-later
Group:          Productivity/Networking/File-Sharing
URL:            https://nextcloud.com/
Source:         https://github.com/nextcloud/desktop/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        sysctl-sync-inotify.conf
# PATCH-FIX-OPENSUSE nextcloud-client-fix-rpath.patch sor.alexei@meowr.ru -- Fix RPATH.
Patch0:         nextcloud-client-fix-rpath.patch
# PATCH-FIX-OPENSUSE nextcloud-client-remove-datetime.patch sor.alexei@meowr.ru -- Remove __TIME__ and __DATE__.
Patch1:         nextcloud-client-remove-datetime.patch
BuildRequires:  AppStream
BuildRequires:  cmake >= 3.2
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  gobject-introspection-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pkgconfig
BuildRequires:  python
BuildRequires:  qtkeychain-qt5-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5WebEngineWidgets)
BuildRequires:  pkgconfig(Qt5WebKitWidgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(openssl) >= 1.1
BuildRequires:  pkgconfig(sqlite3)
Requires:       %{soname}%{sover} = %{version}
Recommends:     %{name}-lang
%if 0%{?is_opensuse}
BuildRequires:  doxygen
BuildRequires:  kio-devel
BuildRequires:  python3-Sphinx
Suggests:       %{name}-doc = %{version}
%endif

%description
The Nextcloud Desktop Client is a tool to synchronise files from
the Nextcloud Server with your computer.

Nextcloud client enables you to connect to your private
Nextcloud Server. With it you can create directories in your home
directory, and keep the contents of those directories synced with
the server. Simply copy a file into the directory and the desktop
synchronisation client does the rest.

%lang_package

%if 0%{?is_opensuse}
%package doc
Summary:        Documentation for nextcloud-client
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
The Nextcloud Desktop Client is a tool to synchronise files from
the Nextcloud Server with your computer.

This package contains the documentation.
%endif

%package -n %{soname}%{sover}
Summary:        The Nextcloud synchronisation library
Group:          System/Libraries

%description -n %{soname}%{sover}
The Nextcloud Desktop Client synchronisation library.

%package -n %{soname}-devel
Summary:        Development files for the Nextcloud synchronisation library
Group:          Development/Libraries/C and C++
Requires:       %{soname}%{sover} = %{version}

%description -n %{soname}-devel
Development files for the Nextcloud Desktop Client synchronisation
library.

%package -n nautilus-extension-nextcloud
Summary:        Nautilus overlay icons
Group:          Productivity/File utilities
Requires:       %{name} = %{version}
Requires:       nautilus
Requires:       python-nautilus
Supplements:    packageand(%{name}:nautilus)
BuildArch:      noarch

%description -n nautilus-extension-nextcloud
This package provides overlay icons to visualise the
synchronisation state in the Nautilus file manager.

%if 0%{?is_opensuse}
%package -n caja-extension-nextcloud
Summary:        Caja overlay icons
Group:          Productivity/File utilities
Requires:       %{name} = %{version}
Requires:       caja
Requires:       python-caja
Supplements:    packageand(%{name}:caja)
BuildArch:      noarch

%description -n caja-extension-nextcloud
This package provides overlay icons to visualise the
synchronisation state in the Caja file manager.

%package -n nemo-extension-nextcloud
Summary:        Nemo overlay icons
Group:          Productivity/File utilities
Requires:       %{name} = %{version}
Requires:       nemo
Requires:       python-nemo
Supplements:    packageand(%{name}:nemo)
BuildArch:      noarch

%description -n nemo-extension-nextcloud
This package provides overlay icons to visualise the
synchronisation state in the Nemo file manager.

%package -n %{name}-dolphin
Summary:        Dolphin overlay icons
Group:          Productivity/File utilities
Requires:       %{name} = %{version}
Requires:       dolphin
Supplements:    packageand(%{name}:dolphin)

%description -n %{name}-dolphin
This package provides the necessary plugin libraries for the
Dolphin filemanager to display overlay icons.
%endif

%prep
%setup -q -n desktop-%{version}
%patch0 -p1
%patch1 -p1
cp -a %{SOURCE1} sysctl-sync-inotify.conf

%build
%cmake \
%if 0%{?is_opensuse}
  -DWITH_DOC=ON          \
%endif
  -DCMAKE_SKIP_RPATH=OFF
%make_jobs

%install
%cmake_install

%if 0%{?is_opensuse}
mkdir -p %{buildroot}%{_docdir}/%{name}-doc/
mv -f %{buildroot}%{_datadir}/doc/client/%{name}/html/ \
  %{buildroot}%{_docdir}/%{name}-doc/html/
%else
# There's no Caja and Nemo in SLE.
rm -r %{buildroot}%{_datadir}/caja-python/
rm -r %{buildroot}%{_datadir}/nemo-python/
%endif

# Generate bytecode for extensions.
for fm in caja nautilus nemo; do
    if [ -d %{buildroot}%{_datadir}/$fm-python/ ]; then
        %py_compile %{buildroot}%{_datadir}/$fm-python/extensions/
    fi
done

# A workaround for gh#owncloud/client#4107
install -Dpm 0644 sysctl-sync-inotify.conf \
  %{buildroot}%{_sysconfdir}/sysctl.d/100-%{name}-sync-inotify.conf

%suse_update_desktop_file nextcloud
%fdupes %{buildroot}%{_datadir}/

%post -n %{soname}%{sover} -p /sbin/ldconfig

%postun -n %{soname}%{sover} -p /sbin/ldconfig

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%license COPYING*
%config %{_sysconfdir}/Nextcloud/
%config %{_sysconfdir}/sysctl.d/100-%{name}-sync-inotify.conf
%{_bindir}/nextcloud*
%dir %{_datadir}/nextcloud/
%{_datadir}/applications/nextcloud.desktop
%dir %{_datadir}/icons/hicolor/1024x1024/
%dir %{_datadir}/icons/hicolor/1024x1024/apps/
%{_datadir}/icons/hicolor/*/apps/Nextcloud*.*

%files lang
%{_datadir}/nextcloud/i18n/

%if 0%{?is_opensuse}
%files doc
%doc %{_docdir}/%{name}-doc/
%endif

%files -n %{soname}%{sover}
%license COPYING*
%{_libdir}/%{soname}.so.*
%dir %{_libdir}/nextcloud/
%{_libdir}/nextcloud/libocsync.so.*

%files -n %{soname}-devel
%{_includedir}/nextcloudsync/
%{_libdir}/%{soname}.so
%{_libdir}/nextcloud/libocsync.so

%files -n nautilus-extension-nextcloud
%dir %{_datadir}/nautilus-python/
%dir %{_datadir}/nautilus-python/extensions/
%{_datadir}/nautilus-python/extensions/syncstate-Nextcloud.py*

%if 0%{?is_opensuse}
%files -n caja-extension-nextcloud
%dir %{_datadir}/caja-python/
%dir %{_datadir}/caja-python/extensions/
%{_datadir}/caja-python/extensions/syncstate-Nextcloud.py*

%files -n nemo-extension-nextcloud
%dir %{_datadir}/nemo-python/
%dir %{_datadir}/nemo-python/extensions/
%{_datadir}/nemo-python/extensions/syncstate-Nextcloud.py*

%files dolphin
%{_libdir}/libnextclouddolphinpluginhelper.so
%{_libdir}/qt5/plugins/nextclouddolphinactionplugin.so
%dir %{_libdir}/qt5/plugins/kf5/overlayicon/
%{_libdir}/qt5/plugins/kf5/overlayicon/nextclouddolphinoverlayplugin.so
%{_datadir}/kservices5/nextclouddolphinactionplugin.desktop
%endif

%changelog
* Thu Dec 12 2019 Franck Bui <fbui@suse.com>
- Update to version 2.5.3:
  * See https://github.com/nextcloud/desktop/compare/v2.5.1...v2.5.3
- Dropped nextcloud-client-fix-qt-5.12.patch: it's included in v2.5.3
* Tue Jan 15 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Stop building with libcloudproviders (boo#1118327).
* Mon Jan  7 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Append to nextcloud-client-fix-qt-5.12.patch a fix for a
  QtWebEngine crash on Qt 5.12 (commit 09b0055, boo#1120310).
* Wed Jan  2 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Add nextcloud-client-fix-qt-5.12.patch: Fix an error during build
  with Qt 5.12 (commit 1295884).
* Tue Dec  4 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.5.1:
  * See https://github.com/nextcloud/desktop/compare/v2.5.0...v2.5.1
* Wed Nov 14 2018 sor.alexei@meowr.ru
- Update to version 2.5.0:
  * See https://github.com/nextcloud/desktop/compare/57bc791...v2.5.0
- Remove nextcloud-client-2.3.3-fix-qt-5.11.patch,
  nextcloud-client-fix-caja-nemo-appnames.patch: fixed upstream.
- Rebase nextcloud-client-fix-rpath.patch,
  nextcloud-client-remove-datetime.patch.
- Build with libcloudproviders.
- Drop openSUSE Leap 42.3 and older support.
* Tue Jun 12 2018 sor.alexei@meowr.ru
- Add nextcloud-client-2.3.3-fix-qt-5.11.patch: Fix Qt 5.11+
  compatibility.
* Thu Mar  1 2018 ecsos@opensuse.org
- fix build error for Tumbleweed
* Mon Dec 25 2017 sor.alexei@meowr.ru
- Use a better tarball.
* Tue Dec  5 2017 sor.alexei@meowr.ru
- Update to version 2.3.3:
  * Chunking NG: Don't use old chunking on new DAV endpoint
    (gh#owncloud/client#5855).
  * Selective Synch: Skip excluded directories when reading DB,
    don't let them show errors (gh#owncloud/client#5772).
  * Settings: Make the window bigger so the Qt version is always
    visible (gh#owncloud/client#5760).
  * Share links: Show a warning that public link shares are public
    (gh#owncloud/client#5786).
  * Downloads: Re-trigger directory discovery on HTTP 404
    (gh#owncloud/client#5799).
  * Notifications: Propagate "Dismiss" as DELETE to server
    (gh#owncloud/client#5922).
  * SynchJournalDB: Don't use ._ as a filename pattern if that does
    not work because of SMB storage settings
    (gh#owncloud/client#5844)
  * SynchJournalDB: Log reason for sqlite3 opening errors.
  * Stop maintaining Qt 4 support.
  * New synch state icon design.
  * Add a state-information icon.
  * Update the icon patch.
* Fri Jul 21 2017 ecsos@opensuse.org
- update to 2.3.2
  * Fix more crashes (thanks to everyone submitting to our crash
    reporter!)
  * Improve compatibility with server 10.0 (5691, X-OC-Total-Size)
  * Share dialog: UI improvements, Bring to front on tray click
  * owncloudcmd: Align process return value with sync return value
    (3936)
  * Fix disk free check on Windows when opening the local DB
- insert Requires: %%{soname}%%{sover} = %%{version} because lib
  does not up- or downgrade by up- or downgrade from client itself.
* Wed Jun 14 2017 sor.alexei@meowr.ru
- Only enable documentation for openSUSE Leap 14.3 and newer
  (boo#1044061).
* Thu Mar 23 2017 sor.alexei@meowr.ru
- Update to version 2.3.1 (changes since 2.2.4):
  * Decreased memory usage during synchronisation.
  * Overlay icons: Lower CPU usage.
  * Allow to not synchronise the server's external storages by
    default.
  * Switch to the new Nextcloud Server WebDAV endpoint.
  * Chunking NG: New file upload chunking algorithm for
    Nextcloud Server 11.0.
  * Allow to synchronise a directory to multiple different servers
    (filename change from .csync_journal.db to _sync_$HASH.db).
  * Conflicts: Use the local mtime for the conflict file name
    (gh#owncloud/client#5273).
  * Add a "Sync now" menu item.
  * Improve SSL Client certificate support (Show UI, Store keys in
    keychain).
  * Propagator: Upload smaller files in parallel.
  * Sync Engine: Read data-fingerprint property to detect backups
    (gh#owncloud/client#2325).
  * GUI: Show link to create an application password/token for
    synchronising.
  * Share dialogue: Add a "Mail link" button.
  * A Caja file manager plugin.
  * Make the "backup detected" message not triggered in wrong cases.
  * SyncEngine: Fix directory renaming when files are changed
    (gh#owncloud/client#5192)
  * Fix a reconnect bug if status.php intermittently returns wrong
    data (gh#owncloud/client#5188).
  * Improve synchronisation scheduling (gh#owncloud/client#5317).
  * Overlay icons: Improvements in correctnes.
  * Tray menu: Only update on demand to fix GNU/Linux desktop
    integration glitches.
  * Progress: Better time/bandwidth estimations.
  * Network: Follow certain HTTP redirects (gh#owncloud/client#2791).
  * Network: Remove all cookies (including load balancers, etc.)
    when logging out.
  * Discovery thread: Low priority.
  * nextcloudsync.log: Write during propagation.
  * Excludes: Consider files in hidden directories excluded
    (gh#owncloud/client#5163).
  * Allow the synchronised directory to be a symlinked directory.
  * Improve HTTP redirect handling (gh#owncloud/client#5555).
  * Blacklist: Escalate repeated soft error to normal error
    (gh#owncloud/client#5500).
  * Fix the URL for linking to application password generation for
    ownCloud 10.0 (gh#owncloud/client#5605).
  * Shibboleth bugfixes.
  * Fixes with regards to low disc space.
  * A tonne of other bugfixes.
  * Refactorings.
  * Improve documentation.
  * Crash fixes.
- Add nextcloud-client-remove-datetime.patch: Remove __TIME__ and
  __DATE__.
- Rebase and rename nextcloud-client-fix-nemo-appname.patch to
  nextcloud-client-fix-caja-nemo-appnames.patch.
- Remove nextcloud-client-fix-dolphin.patch,
  nextcloud-client-fix-ru-typo.patch,
  nextcloud-client-fix-tray-workaround.patch: fixed upstream.
- Rename 100-sync-inotify.conf to the less conflicting
  100-nextcloud-sync-inotify.conf.
* Fri Feb  3 2017 sor.alexei@meowr.ru
- Add nextcloud-client-fix-dolphin.patch from bruno_friedmann to
  fix the Dolphin plugin.
* Tue Jan 24 2017 sor.alexei@meowr.ru
- Add nextcloud-client-fix-tray-workaround.patch: fix the tray
  workaround (from commit 98efb07 of owncloud-client).
* Fri Sep 30 2016 ecsos@opensuse.org
- Update to version 2.2.4:
  * Dolphin Plugin: Use the Application name for the socket path
    (gh#owncloud/client#5172).
  * SyncEngine: Fix renaming of directories when files are changed
    (gh#owncloud/client#5195).
  * Selective Sync: Fix HTTP request loop and show error in view
    (gh#owncloud/client#5154).
  * ConnectionValidator: Properly handle error in status.php
    request (gh#owncloud/client#5188).
  * Discovery: Set thread priority to low (gh#owncloud/client#5017).
  * ExcludeFiles: Fix when the directory casing is not the same in
    the settings and in the FS.
  * ShareLink: Ensure the password line edit is enabled
    (gh#owncloud/client#5117).
* Fri Aug 26 2016 sor.alexei@meowr.ru
- Initial package.
